pub async fn report_task_failure(
error_tx: &Sender<StreamError>,
task_id: u32,
task_name: &str,
err: StreamError,
)Expand description
Log and send a task failure to the job error channel (logs again if send fails).
pub async fn report_task_failure(
error_tx: &Sender<StreamError>,
task_id: u32,
task_name: &str,
err: StreamError,
)Log and send a task failure to the job error channel (logs again if send fails).